netapp_ontap.models.nvme_interface_fc_interface API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nvme_interface_fc_interface`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NvmeInterfaceFcInterfaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NvmeInterfaceFcInterface object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the nvme_interface_fc_interface.

  `port: FcPort GET POST PATCH`

    The port field of the nvme_interface_fc_interface.

  `wwnn: str GET`

    The WWNN (world wide node name) of the Fibre Channel NVMe interface.

    Example: 20:00:00:50:56:b4:13:a9

  `wwpn: str GET`

    The WWPN (world wide port name) of the Fibre Channel NVMe interface.

    Example: 20:00:00:50:56:b4:13:a8